Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
DefaultSetup = Setup{'│', '─', '┼', '┬', '┴', '├', '┤', '┌', '┐', '└', '┘'}
)
Functions ¶
This section is empty.
Types ¶
type Cell ¶
type Cell struct {
// Content is an array of lines in this cell.
Content []string
// ColSpan specifies how many cells this one should span. If you have a
// table with four columns and the first cell should be 2 columns wide, set
// this to 2 in the first cell and do not use the second cell, it will be
// ignored. So your Cells array in the row still has four elements. Setting
// ColSpan to 0 or 1 has the same default effect of just spanning one cell.
//
// The WidthMin and WidthMax properties of cells with ColSpan > 1 will be
// ignoered. Setting restrictions for such cells is not possible currently.
ColSpan uint
HAlign Alignment
WidthMin uint32
WidthMax uint32
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.